@@ -7,55 +7,63 @@
 **
 **  (c) 2000 Dr. Andreas Mueller
 **
-**  $Id: certmap.c,v 1.7 2004/03/30 23:35:50 afm Exp $
+**  $Id: certmap.c,v 1.12 2010/02/06 09:55:03 afm Exp $
 */ 
 #include "mod_authz_ldap.h"
-#ifdef EAPI
 #include <openssl/pem.h>
 #include <openssl/x509v3.h>
+#ifdef AUTHZ_LDAP_HAVE_SSL
 extern char	*ssl_var_lookup(apr_pool_t *, server_rec *, conn_rec *,
 			request_rec *, char *);
-#ifndef AUTHZ_LDAP_HAVE_SSL
-#define AUTHZ_LDAP_HAVE_SSL
+#else
+static int	sslwarningsent = 0;
+static void	sendsslwarning(request_rec *r) {
+	if (sslwarningsent) {
+		return;
+	}
+	ap_log_rerror(APLOG_MARK, APLOG_NOERRNO|APLOG_ERR, 0,
+		r, "[%d] SSL specific function in mod_authz_ldap called, "
+			"but module compiled without SSL support",
+		(int)getpid());
+	sslwarningsent = 1;
+	return;
+}
 #endif /* AUTHZ_LDAP_HAVE_SSL */
-#endif /* EAPI */
 
 /*************************************************************************
 ** Certificate Retrieval						**
 *************************************************************************/
 
-static char	*authz_ldap_get_issuer_dn(request_rec *r) {
+static char	*authz_ldap_get_issuer_dn(authz_ldap_config_rec *sec,
+			request_rec *r) {
 #ifdef AUTHZ_LDAP_HAVE_SSL
 	char			*issuer_dn;
-	authz_ldap_config_rec	*sec;
 
-	sec = ap_get_module_config(r->per_dir_config, &authz_ldap_module);
 	issuer_dn = ssl_var_lookup(r->pool, r->server, r->connection, r,
 		"SSL_CLIENT_I_DN");
-	AUTHZ_DEBUG3("[%d] client issuer DN: %s", (int)getpid(),
+	AUTHZ_RDEBUG("[%d] client issuer DN: %s", (int)getpid(),
 		(issuer_dn) ? issuer_dn : "(null)");
 	return issuer_dn;
 #else /* AUTHZ_LDAP_HAVE_SSL */
+	sendsslwarning(r);
 	return NULL;
 #endif /* AUTHZ_LDAP_HAVE_SSL */
 }
 
-static char	*authz_ldap_get_certificate(request_rec *r) {
+static char	*authz_ldap_get_certificate(authz_ldap_config_rec *sec,
+			request_rec *r) {
 #ifdef AUTHZ_LDAP_HAVE_SSL
 	BIO		*bio_mem;
 	int		l, j;
 	unsigned char	*v;
 	char		*xp, *cp, *p;
-	authz_ldap_config_rec	*sec;
 	X509		*xs;
 
-	sec = ap_get_module_config(r->per_dir_config, &authz_ldap_module);
-
 	/* retrieve the certificate in PEM form				*/
 	xp = ssl_var_lookup(r->pool, r->server, r->connection, r,
 		"SSL_CLIENT_CERT");
 	if (NULL == xp) { 
-		AUTHZ_DEBUG2("[%d] not certificate found", (int)getpid());
+		AUTHZ_RDEBUG("[%d] not certificate found", (int)getpid());
 		return NULL;
 	}
 
@@ -65,7 +73,7 @@ static char	*authz_ldap_get_certificate(request_rec *r) {
 	xs = PEM_read_bio_X509(bio_mem, NULL, NULL, NULL);
 	BIO_free(bio_mem);
 	if (NULL == xs) {
-		AUTHZ_DEBUG3("[%d] could not read certificate from PEM: %s",
+		AUTHZ_RDEBUG("[%d] could not read certificate from PEM: %s",
 			(int)getpid(), xp);
 		return NULL;
 	}
@@ -74,56 +82,56 @@ static char	*authz_ldap_get_certificate(request_rec *r) {
 	bio_mem = BIO_new(BIO_s_mem());
 	i2d_X509_bio(bio_mem, xs);
 	l = BIO_ctrl_pending(bio_mem);
-	v = ap_palloc(r->pool, l);
+	v = apr_palloc(r->pool, l);
 	BIO_read(bio_mem, v, l);
 	BIO_free(bio_mem);
 
 	/* quote the whole stuff so that it can safely be used in a 	*/
 	/* filter							*/
-	cp = ap_palloc(r->pool, 3 * l + 1);
+	cp = apr_palloc(r->pool, 3 * l + 1);
 	p = cp;
 	for (j = 0; j < l; j++) {
-		ap_snprintf(p, 4, "\\%02x", (unsigned char)v[j]);
+		apr_snprintf(p, 4, "\\%02x", (unsigned char)v[j]);
 		p += 3;
 	}
 
 	/* return the quoted certificate				*/
 	return cp;
 #else /* AUTHZ_LDAP_HAVE_SSL */
+	sendsslwarning(r);
 	return NULL;
 #endif /* AUTHZ_LDAP_HAVE_SSL */
 }
 
-static char	*authz_ldap_get_subject_dn(request_rec *r) {
+static char	*authz_ldap_get_subject_dn(authz_ldap_config_rec *sec,
+			request_rec *r) {
 #ifdef AUTHZ_LDAP_HAVE_SSL
 	char	*subject_dn;
-	authz_ldap_config_rec	*sec;
 
-	sec = ap_get_module_config(r->per_dir_config, &authz_ldap_module);
 	subject_dn = ssl_var_lookup(r->pool, r->server, r->connection, r,
 		"SSL_CLIENT_S_DN");
-	AUTHZ_DEBUG3("[%d] client subject DN: %s", (int)getpid(),
+	AUTHZ_RDEBUG("[%d] client subject DN: %s", (int)getpid(),
 		(subject_dn) ? subject_dn : "(null)");
 	return subject_dn;
 #else /* AUTHZ_LDAP_HAVE_SSL */
+	sendsslwarning(r);
 	return NULL;
 #endif /* AUTHZ_LDAP_HAVE_SSL */
 }
 
-static char	*authz_ldap_get_certserial(request_rec *r) {
+static char	*authz_ldap_get_certserial(authz_ldap_config_rec *sec,
+			request_rec *r) {
 #ifdef AUTHZ_LDAP_HAVE_SSL
 	char	*cp;
-	authz_ldap_config_rec	*sec;
-
-	sec = ap_get_module_config(r->per_dir_config, &authz_ldap_module);
 
 	/* get serial number from X509 client certificate		*/
 	cp = ssl_var_lookup(r->pool, r->server, r->connection, r,
 		"SSL_CLIENT_M_SERIAL");
-	AUTHZ_DEBUG3("[%d] client serial: %s", (int)getpid(),
+	AUTHZ_RDEBUG("[%d] client serial: %s", (int)getpid(),
 		(cp) ? cp : "(null)");
 	return cp;
 #else /* AUTHZ_LDAP_HAVE_SSL */
+	sendsslwarning(r);
 	return NULL;
 #endif /* AUTHZ_LDAP_HAVE_SSL */
 }
@@ -160,7 +168,8 @@ static char	*authz_ldap_get_certserial(request_rec *r) {
 	products.
 
  */
-char	*authz_ldap_get_ms_x500_alt_security_identity(request_rec *r) {
+char	*authz_ldap_get_ms_x500_alt_security_identity(
+		authz_ldap_config_rec *sec, request_rec *r) {
 #ifdef AUTHZ_LDAP_HAVE_SSL
 	BIO		*bio_mem;
 	int		l;
@@ -168,17 +177,14 @@ char	*authz_ldap_get_ms_x500_alt_security_identity(request_rec *r) {
 	char		*xp;
 	char		*p, *q;
 	int		at_boundary;
-	authz_ldap_config_rec	*sec;
 	X509		*xs;
 	X509_NAME	*name;
 
-	sec = ap_get_module_config(r->per_dir_config, &authz_ldap_module);
-
 	/* retrieve the certificate in PEM form				*/
 	xp = ssl_var_lookup(r->pool, r->server, r->connection, r,
 		"SSL_CLIENT_CERT");
 	if (NULL == xp) { 
-		AUTHZ_DEBUG2("[%d] not certificate found", (int)getpid());
+		AUTHZ_RDEBUG("[%d] not certificate found", (int)getpid());
 		return NULL;
 	}
 
@@ -188,7 +194,7 @@ char	*authz_ldap_get_ms_x500_alt_security_identity(request_rec *r) {
 	xs = PEM_read_bio_X509(bio_mem, NULL, NULL, NULL);
 	BIO_free(bio_mem);
 	if (NULL == xs) {
-		AUTHZ_DEBUG3("[%d] could not read certificate from PEM: %s",
+		AUTHZ_RDEBUG("[%d] could not read certificate from PEM: %s",
 			(int)getpid(), xp);
 		return NULL;
 	}
@@ -216,7 +222,7 @@ char	*authz_ldap_get_ms_x500_alt_security_identity(request_rec *r) {
 	X509_free(xs);
 
 	l = BIO_ctrl_pending(bio_mem);
-	v = ap_palloc(r->pool, l);
+	v = apr_palloc(r->pool, l);
 	BIO_read(bio_mem, v, l);
 	BIO_free(bio_mem);
 
@@ -238,10 +244,11 @@ char	*authz_ldap_get_ms_x500_alt_security_identity(request_rec *r) {
 			at_boundary = 0;
 	}
 	*q = *p;
-	AUTHZ_DEBUG3("[%d] client MS X500 altSecurityIdentity: %s", (int)getpid(),
+	AUTHZ_RDEBUG("[%d] client MS X500 altSecurityIdentity: %s", (int)getpid(),
 		(v) ? v : "(null)");
 	return v;
 #else /* AUTHZ_LDAP_HAVE_SSL */
+	sendsslwarning(r);
 	return NULL;
 #endif /* AUTHZ_LDAP_HAVE_SSL */
 }
@@ -249,24 +256,22 @@ char	*authz_ldap_get_ms_x500_alt_security_identity(request_rec *r) {
 /* OID used as othername to carry the userPrincipalName according to MS */
 #define USER_PRINCIPAL_NAME_OID		"1.3.6.1.4.1.311.20.2.3"
 
-char	*authz_ldap_get_ms_user_principal_name(request_rec *r) {
+char	*authz_ldap_get_ms_user_principal_name(authz_ldap_config_rec *sec,
+		request_rec *r) {
 #ifdef AUTHZ_LDAP_HAVE_SSL
 	BIO		*bio_mem;
 	int		l;
 	char		*v;
 	char		*xp;
-	authz_ldap_config_rec	*sec;
 	X509		*xs;
 	int		extension_index;
 	ASN1_OBJECT	*upnoid;
 
-	sec = ap_get_module_config(r->per_dir_config, &authz_ldap_module);
-
 	/* retrieve the certificate in PEM form				*/
 	xp = ssl_var_lookup(r->pool, r->server, r->connection, r,
 		"SSL_CLIENT_CERT");
 	if (NULL == xp) { 
-		AUTHZ_DEBUG2("[%d] not certificate found", (int)getpid());
+		AUTHZ_RDEBUG("[%d] not certificate found", (int)getpid());
 		return NULL;
 	}
 
@@ -276,7 +281,7 @@ char	*authz_ldap_get_ms_user_principal_name(request_rec *r) {
 	xs = PEM_read_bio_X509(bio_mem, NULL, NULL, NULL);
 	BIO_free(bio_mem);
 	if (NULL == xs) {
-		AUTHZ_DEBUG3("[%d] could not read certificate from PEM: %s",
+		AUTHZ_RDEBUG("[%d] could not read certificate from PEM: %s",
 			(int)getpid(), xp);
 		return NULL;
 	}
@@ -294,14 +299,14 @@ char	*authz_ldap_get_ms_user_principal_name(request_rec *r) {
 
 		extension = X509_get_ext(xs, extension_index);
 		if ( !extension ) {
-			AUTHZ_DEBUG3("[%d] error getting subjectaltname with index %d",
+			AUTHZ_RDEBUG("[%d] error getting subjectaltname with index %d",
 				     (int)getpid(), extension_index);
 			X509_free(xs);
 			return NULL;
 		}
 		subjectaltnames = X509V3_EXT_d2i(extension);
 		if ( !subjectaltnames ) {
-			AUTHZ_DEBUG3("[%d] error parsing subjectaltname with index %d",
+			AUTHZ_RDEBUG("[%d] error parsing subjectaltname with index %d",
 				     (int)getpid(), extension_index);
 			X509_free(xs);
 			return NULL;
@@ -316,29 +321,29 @@ char	*authz_ldap_get_ms_user_principal_name(request_rec *r) {
 		subjectaltname = sk_GENERAL_NAME_value(subjectaltnames, 0);
 	  
 		if ( subjectaltname->type != GEN_OTHERNAME ) {
-			AUTHZ_DEBUG3("[%d] seen subjectaltname of different type %d",
+			AUTHZ_RDEBUG("[%d] seen subjectaltname of different type %d",
 				     (int)getpid(), subjectaltname->type);
 			continue;
 		} else if ( OBJ_cmp(subjectaltname->d.otherName->type_id,
 				    upnoid) ) {
-			AUTHZ_DEBUG3("[%d] seen othername of different type %s",
+			AUTHZ_RDEBUG("[%d] seen othername of different type %s",
 				     (int)getpid(), "TBD");
 			continue;
 		} else if ( subjectaltname->d.otherName->value->type !=
 			    V_ASN1_UTF8STRING) {
-			AUTHZ_DEBUG3("[%d] seen userPrincipalName with different string type %d",
+			AUTHZ_RDEBUG("[%d] seen userPrincipalName with different string type %d",
 				     (int)getpid(),
 				     subjectaltname->d.otherName->value->type);
 			continue;
 		} else {
 	  		/* copy the value out */
 			l = subjectaltname->d.otherName->value->value.utf8string->length;
-			v = ap_palloc(r->pool, l+1);
+			v = apr_palloc(r->pool, l+1);
 			memcpy(v,
 			       subjectaltname->d.otherName->value->value.utf8string->data,
 			       l);
 			v[l] = '\0';
-			AUTHZ_DEBUG3("[%d] found userPrincipalName: %s",
+			AUTHZ_RDEBUG("[%d] found userPrincipalName: %s",
 				     (int)getpid(), v);
 			break;
 		}
@@ -348,6 +353,7 @@ char	*authz_ldap_get_ms_user_principal_name(request_rec *r) {
 
 	return v;
 #else /* AUTHZ_LDAP_HAVE_SSL */
+	sendsslwarning(r);
 	return NULL;
 #endif /* AUTHZ_LDAP_HAVE_SSL */
 }
@@ -365,8 +371,7 @@ static void	authz_ldap_escape_parentheses(char *org, char *new) {
 
 /* utility function: map a certificate to a user name			*/
 /* returns 1 if mapping was successful, 0 otherwise			*/
-int	authz_ldap_map_user(request_rec *r) {
-	authz_ldap_config_rec	*sec;
+int	authz_ldap_map_user(authz_ldap_config_rec *sec, request_rec *r) {
 	char			dn[MAX_STRING_LEN];
 	char			*attr, *issuer, *subject, *serial,
 				*certificate;
@@ -384,47 +389,45 @@ int	authz_ldap_map_user(request_rec *r) {
 	char			escaped_issuer[MAX_STRING_LEN];
 	char			escaped_subject[MAX_STRING_LEN];
 
-	sec = ap_get_module_config(r->per_dir_config, &authz_ldap_module);
-
 	/* if the connection notes table contains a value for 		*/
 	/* authz_ldap::userdn, the mapping for the certificate was	*/
 	/* successful, and we don't need to map again.			*/
-	userdn = authz_ldap_get_userdn(r);
+	userdn = authz_ldap_get_userdn(sec, r);
 	if ((userdn != NULL) && (strlen(userdn) > 0)) {
-		AUTHZ_DEBUG3("[%d] user mapping known: %s", (int)getpid(),
+		AUTHZ_RDEBUG("[%d] user mapping known: %s", (int)getpid(),
 			userdn);
 		return 1;
 	}
 
 	/* find issuer and subject distinguished name (short form)	*/
-	issuer = authz_ldap_get_issuer_dn(r);
+	issuer = authz_ldap_get_issuer_dn(sec, r);
 	if (NULL == issuer) {
-		AUTHZ_DEBUG2("[%d] issuer not found in certificate",
+		AUTHZ_RDEBUG("[%d] issuer not found in certificate",
 			(int)getpid());
 		return 0;
 	}
 	authz_ldap_escape_parentheses(issuer, escaped_issuer);
 
-	subject = authz_ldap_get_subject_dn(r);
+	subject = authz_ldap_get_subject_dn(sec, r);
 	if (NULL == subject) {
-		AUTHZ_DEBUG2("[%d] subject not found in certificate",
+		AUTHZ_RDEBUG("[%d] subject not found in certificate",
 			(int)getpid());
 		return 0;
 	}
 	authz_ldap_escape_parentheses(subject, escaped_subject);
-	authz_ldap_set_subject(r, subject);
+	authz_ldap_set_subject(sec, r, subject);
 
-	serial = authz_ldap_get_certserial(r);
+	serial = authz_ldap_get_certserial(sec, r);
 	if (NULL == serial) {
-		AUTHZ_DEBUG2("[%d] serial not found in certificate",
+		AUTHZ_RDEBUG("[%d] serial not found in certificate",
 			(int)getpid());
 		return 0;
 	}
-	authz_ldap_set_serial(r, serial);
+	authz_ldap_set_serial(sec, r, serial);
 
-	certificate = authz_ldap_get_certificate(r);
+	certificate = authz_ldap_get_certificate(sec, r);
 	if (NULL == certificate) {
-		AUTHZ_DEBUG2("[%d] certificate not found in certificate",
+		AUTHZ_RDEBUG("[%d] certificate not found in certificate",
 			(int)getpid());
 		return 0;
 	}
@@ -432,62 +435,63 @@ int	authz_ldap_map_user(request_rec *r) {
 	/* there are essentially four mapping functions, here is how	*/
 	/* the right one gets selected:					*/
 	if (AUTHMAPMETHOD_NONE == sec->mapmethod) {
-		AUTHZ_DEBUG2("[%d] map method none called, should not happen",
+		AUTHZ_RDEBUG("[%d] map method none called, should not happen",
 			(int)getpid());
 		return 0;
 	}
 
 	/* build a filter for the certificate map			*/
 	if (AUTHMAPMETHOD_CERTIFICATE == sec->mapmethod) {
-		ap_snprintf(filter, MAX_STRING_LEN,
+		apr_snprintf(filter, MAX_STRING_LEN,
 			"(&(userCertificate=%s)"
 			"(objectClass=strongAuthenticationUser))", certificate);
 		base = sec->userbase;
 		scope = sec->userscope;
-		AUTHZ_DEBUG2("[%d] preparing certificate search",
+		AUTHZ_RDEBUG("[%d] preparing certificate search",
 			(int)getpid());
 	}
 	if (AUTHMAPMETHOD_ISSUERSERIAL == sec->mapmethod) {
-		ap_snprintf(filter, MAX_STRING_LEN,
+		apr_snprintf(filter, MAX_STRING_LEN,
 			"(&(issuerDN=%s)(serialNumber=%s)"
 			"(objectClass=authzLDAPmap))", escaped_issuer, serial);
 		base = sec->mapbase;
 		scope = sec->mapscope;
-		AUTHZ_DEBUG2("[%d] preparing issuer/serial search",
+		AUTHZ_RDEBUG("[%d] preparing issuer/serial search",
 			(int)getpid());
 	}
 	if (AUTHMAPMETHOD_ISSUERSUBJECT == sec->mapmethod) {
-		ap_snprintf(filter, MAX_STRING_LEN,
+		apr_snprintf(filter, MAX_STRING_LEN,
 			"(&(issuerDN=%s)(subjectDN=%s)"
 			"(objectClass=authzLDAPmap))",
 			escaped_issuer, escaped_subject);
 		base = sec->mapbase;
 		scope = sec->mapscope;
-		AUTHZ_DEBUG2("[%d] preparing issuer/subject search",
+		AUTHZ_RDEBUG("[%d] preparing issuer/subject search",
 			(int)getpid());
 	}
 	if (AUTHMAPMETHOD_AD == sec->mapmethod) {
 		char * ms_upn;
 		char * ms_asi;
-		AUTHZ_DEBUG2("[%d] embarking on active directory search",
+		AUTHZ_RDEBUG("[%d] embarking on active directory search",
 			(int)getpid());
-		if (NULL != (ms_upn = authz_ldap_get_ms_user_principal_name(r))) {
-			ap_snprintf(filter, MAX_STRING_LEN,
+		if (NULL != (ms_upn = authz_ldap_get_ms_user_principal_name(
+				sec, r))) {
+			apr_snprintf(filter, MAX_STRING_LEN,
 				    "(userPrincipalName=%s)", ms_upn);
-		} else if (NULL != (ms_asi =
-			    authz_ldap_get_ms_x500_alt_security_identity(r))) {
-			ap_snprintf(filter, MAX_STRING_LEN,
+		} else if (NULL != (ms_asi
+		    = authz_ldap_get_ms_x500_alt_security_identity(sec, r))) {
+			apr_snprintf(filter, MAX_STRING_LEN,
 				    "(altSecurityIdentities=%s)", ms_asi);
 		} else {
-			AUTHZ_DEBUG2("[%d] mapping for AD failed: ",
+			AUTHZ_RDEBUG("[%d] mapping for AD failed: ",
 				     (int)getpid());
-			ap_snprintf(filter, MAX_STRING_LEN,
+			apr_snprintf(filter, MAX_STRING_LEN,
 				    "(nosuchattribute=nosuchvalue)");
 		}
 		base = sec->mapbase;
 		scope = sec->mapscope;
 	}
-	AUTHZ_DEBUG4("[%d] authz_ldap_search for certificate mapping: "
+	AUTHZ_RDEBUG("[%d] authz_ldap_search for certificate mapping: "
 		"base = %s, filter = %s", (int)getpid(), sec->mapbase, filter);
 
 	/* we have to retrieve the dn from the directory, which is 	*/
@@ -497,12 +501,12 @@ int	authz_ldap_map_user(request_rec *r) {
 	if (AUTHMAPMETHOD_NEEDSOWNER(sec->mapmethod)) {
 		attrs[attr_index] = "owner";
 		attr_index++;
-		AUTHZ_DEBUG2("[%d] authz_ldap need owner", (int)getpid());
+		AUTHZ_RDEBUG("[%d] authz_ldap need owner", (int)getpid());
 	}
 	if (sec->mapusertoattr) {
 		attrs[attr_index] = sec->mapusertoattr;
 		attr_index++;
-		AUTHZ_DEBUG3("[%d] authz_ldap need attribute: %s",
+		AUTHZ_RDEBUG("[%d] authz_ldap need attribute: %s",
 			(int)getpid(), sec->mapusertoattr);
 	}
 	if ( attr_index == 0 ) {
@@ -511,11 +515,11 @@ int	authz_ldap_map_user(request_rec *r) {
   	}
 	attrs[attr_index] = NULL;
 	/*attrs[1] = NULL; this seems to be wrong */
-	if (authz_ldap_search(r, base, scope,
+	if (authz_ldap_search(sec, r, base, scope,
 		filter, attrs, 0, &result) != LDAP_SUCCESS) {
 		if (sec->loglevel >= APLOG_ERR)
-		ap_log_rerror(APLOG_MARK, APLOG_NOERRNO|APLOG_ERR,
-			APLOG_STATUS r,
+		ap_log_rerror(APLOG_MARK, APLOG_NOERRNO|APLOG_ERR, 0,
+			r,
 			"[%d] certificate owner for [ %s | %s ] not found",
 			(int)getpid(), issuer, subject);
 		return 0;
@@ -526,8 +530,8 @@ int	authz_ldap_map_user(request_rec *r) {
 	if (nentries == 0) {
 		ldap_msgfree(result);
 		if (sec->loglevel >= APLOG_ERR)
-		ap_log_rerror(APLOG_MARK, APLOG_NOERRNO|APLOG_ERR,
-			APLOG_STATUS r,
+		ap_log_rerror(APLOG_MARK, APLOG_NOERRNO|APLOG_ERR, 0,
+			r,
 			"[%d] filter: %s base: %s, no such user", (int)getpid(),
 			filter, base);
 		return 0;
@@ -535,8 +539,8 @@ int	authz_ldap_map_user(request_rec *r) {
 	if (nentries > 1) {
 		ldap_msgfree(result);
 		if (sec->loglevel >= APLOG_ERR)
-		ap_log_rerror(APLOG_MARK, APLOG_NOERRNO|APLOG_ERR,
-			APLOG_STATUS r,
+		ap_log_rerror(APLOG_MARK, APLOG_NOERRNO|APLOG_ERR, 0,
+			r,
 			"[%d] filter: %s base: %s, not unique", (int)getpid(),
 			filter, base);
 		return 0;
@@ -553,8 +557,8 @@ int	authz_ldap_map_user(request_rec *r) {
 			d = ldap_get_dn(sec->ldap, e);
 			apr_cpystrn(dn, d, MAX_STRING_LEN);
 			ldap_memfree(d);
-			authz_ldap_set_userdn(r, dn);
-			AUTHZ_DEBUG3("[%d] userdn set to %s", (int)getpid(),
+			authz_ldap_set_userdn(sec, r, dn);
+			AUTHZ_RDEBUG("[%d] userdn set to %s", (int)getpid(),
 				dn);
 
 			/* if mapping to an attribute is requested	*/
@@ -567,8 +571,8 @@ int	authz_ldap_map_user(request_rec *r) {
 					apr_cpystrn(newname, vals[0],
 						MAX_STRING_LEN);
 					/* remember the mapped name	*/
-					authz_ldap_set_mapped(r, newname);
-					AUTHZ_DEBUG3("[%d] mapped set to %s",
+					authz_ldap_set_mapped(sec, r, newname);
+					AUTHZ_RDEBUG("[%d] mapped set to %s",
 						(int)getpid(), newname);
 					ldap_value_free(vals);
 				}
@@ -584,19 +588,19 @@ int	authz_ldap_map_user(request_rec *r) {
 				if (vals != NULL) {
 					apr_cpystrn(dn, vals[0], MAX_STRING_LEN);
 					ldap_value_free(vals);
-					authz_ldap_set_userdn(r, dn);
-					AUTHZ_DEBUG4("[%d] userdn set to %s from [%s]",
+					authz_ldap_set_userdn(sec, r, dn);
+					AUTHZ_RDEBUG("[%d] userdn set to %s from [%s]",
 						(int)getpid(), dn, attr);
 					if (sec->mapusertoattr) {
-						AUTHZ_DEBUG3("[%d] fetching map attribute [%s]",
+						AUTHZ_RDEBUG("[%d] fetching map attribute [%s]",
 							(int)getpid(), sec->mapusertoattr );
 
 						vals = ldap_get_values(sec->ldap, e,
 							sec->mapusertoattr);
 						if (vals != NULL) {
 							apr_cpystrn(newname, vals[0], MAX_STRING_LEN);
-							authz_ldap_set_mapped(r, newname);
-							AUTHZ_DEBUG4("[%d] mapped set to %s from [%s]",
+							authz_ldap_set_mapped(sec, r, newname);
+							AUTHZ_RDEBUG("[%d] mapped set to %s from [%s]",
 								(int)getpid(), newname, sec->mapusertoattr);
 							ldap_value_free(vals);
 						}
@@ -612,12 +616,12 @@ int	authz_ldap_map_user(request_rec *r) {
 	}
 	ldap_msgfree(result);
 
-	AUTHZ_DEBUG3("[%d] owner dn: %s", (int)getpid(),
-		authz_ldap_get_userdn(r));
+	AUTHZ_RDEBUG("[%d] owner dn: %s", (int)getpid(),
+		authz_ldap_get_userdn(sec, r));
 
 	/* set the the user to the distinguished name of the		*/
 	/* certificate owner						*/
-	AUTHZ_DEBUG5("[%d] user [ %s | %s ] mapped to '%s'", (int)getpid(),
+	AUTHZ_RDEBUG("[%d] user [ %s | %s ] mapped to '%s'", (int)getpid(),
 		issuer, subject, newname ? newname : dn);
 
 	/* that's it, if we get to this point, we can assume the 	*/
