@@ -7,31 +7,10 @@
 **
 **  (c) 2001 Dr. Andreas Mueller
 **
-**  $Id: modconf.c,v 1.10 2004/03/30 23:35:50 afm Exp $
+**  $Id: modconf.c,v 1.13 2010/02/06 09:24:18 afm Exp $
 */ 
 #include "mod_authz_ldap.h"
 
-#ifndef AP_SERVER_MAJORVERSION
-/* The content handler */
-/* XXX it is planned that this displays statistics about the module	*/
-static int authz_ldap_handler(request_rec *r)
-{
-    r->content_type = "text/html";      
-    ap_send_http_header(r);
-    if (!r->header_only)
-        ap_rputs("Authz_LDAP statistics are not yet implemented.\n", r);
-    return OK;
-}
-#endif /* AP_SERVER_MAJORVERSION */
-
-#ifndef AP_SERVER_MAJORVERSION
-/* Dispatch list of content handlers */
-const handler_rec authz_ldap_handlers[] = { 
-    { "authz_ldap", authz_ldap_handler }, 
-    { NULL, NULL }
-};
-#endif /* AP_SERVER_MAJORVERSION */
-
 /*************************************************************************
 ** Configuration							**
 *************************************************************************/
@@ -42,10 +21,8 @@ static const char	*authz_ldap_set_user_scope_slot(cmd_parms *parms,
 	authz_ldap_config_rec	*sec;
 	sec = (authz_ldap_config_rec *)mconfig;
 
-#ifdef AUTHZ_LDAP_DEBUG
-	fprintf(stderr, "%s:%d: setting user search scope at %p to '%s'\n",
-		__FILE__, __LINE__, (void *)sec, (arg) ? arg : "(null)");
-#endif
+	AUTHZ_DEBUG("setting user search scope at %x to '%s'", parms->server,
+		(void *)sec, (arg) ? arg : "(null)");
 	/* check for correct directives					*/
 	if (0 == strcasecmp("subtree", arg)) {
 		sec->userscope = LDAP_SCOPE_SUBTREE;
@@ -64,10 +41,8 @@ static const char	*authz_ldap_set_group_scope_slot(cmd_parms *parms,
 	authz_ldap_config_rec	*sec;
 	sec = (authz_ldap_config_rec *)mconfig;
 
-#ifdef AUTHZ_LDAP_DEBUG
-	fprintf(stderr, "%s:%d: setting group search scope at %p to '%s'\n",
-		__FILE__, __LINE__, (void *)sec, (arg) ? arg : "(null)");
-#endif
+	AUTHZ_DEBUG("setting group search scope at %x to '%s'", parms->server,
+		(void *)sec, (arg) ? arg : "(null)");
 	/* check for correct directives					*/
 	if (0 == strcasecmp("subtree", arg)) {
 		sec->groupscope = LDAP_SCOPE_SUBTREE;
@@ -86,10 +61,8 @@ static const char	*authz_ldap_set_map_scope_slot(cmd_parms *parms,
 	authz_ldap_config_rec	*sec;
 	sec = (authz_ldap_config_rec *)mconfig;
 
-#if AUTHZ_LDAP_DEBUG
-	fprintf(stderr, "%s:%d: setting map search scope at %p to '%s'\n",
-		__FILE__, __LINE__, (void *)sec, (arg) ? arg : "(null)");
-#endif
+	AUTHZ_DEBUG("setting map search scope at %x to '%s'", parms->server,
+		(void *)sec, (arg) ? arg : "(null)");
 	/* check for correct directives					*/
 	if (0 == strcasecmp("subtree", arg)) {
 		sec->mapscope = LDAP_SCOPE_SUBTREE;
@@ -108,10 +81,8 @@ static const char	*authz_ldap_set_loglevel_slot(cmd_parms *parms,
 	authz_ldap_config_rec	*sec;
 	sec = (authz_ldap_config_rec *)mconfig;
 
-#if AUTHZ_LDAP_DEBUG
-	fprintf(stderr, "%s:%d: setting loglevel at %p to '%s'\n",
-		__FILE__, __LINE__, (void *)sec, (arg) ? arg : "(null)");
-#endif
+	AUTHZ_DEBUG("setting loglevel at %x to '%s'",
+		(void *)sec, (arg) ? arg : "(null)");
 	/* check for the various possible legal values of the argument	*/
 	if (0 == strcasecmp("emerg", arg)) {
 		sec->loglevel = APLOG_EMERG; return NULL;
@@ -140,72 +111,18 @@ static const char	*authz_ldap_set_loglevel_slot(cmd_parms *parms,
 	return "illegal argument to AuthzLDAPLogLevel";
 }
 
-#ifdef HAVE_LDAP_ENABLE_CACHE
-/*
- * This part of the code implements the configuration parameters for
- * the LDAP cache, and is only compiled into the code if the library
- * implements the ldap_enable_cache function.
- */
-
-/* read the cache timeout from the configuration			*/
-static const char	*authz_ldap_set_timeout_slot(cmd_parms *parms,
-	void *mconfig, const char *arg) {
-	authz_ldap_config_rec	*sec;
-	sec = (authz_ldap_config_rec *)mconfig;
-
-#if AUTHZ_LDAP_DEBUG
-	fprintf(stderr, "%s:%d: setting timeout at %p to '%s'\n",
-		__FILE__, __LINE__, (void *)sec, (arg) ? arg : "(null)");
-#endif
-
-	sec->timeout = atoi(arg);
-	if ((sec->timeout < 0) || (sec->timeout > 86400)) {
-		ap_log_error(APLOG_MARK, APLOG_ERR, APLOG_STATUS parms->server,
-			"[%d] illegal LDAP cache timeout: %d, using default %d",
-			(int)getpid(), sec->timeout,
-			AUTHZ_DEFAULT_CACHE_TIMEOUT);
-		sec->timeout = AUTHZ_DEFAULT_CACHE_TIMEOUT;
-	}
-	return NULL;
-}
-
-/* read the cache size from the configuration				*/
-static const char	*authz_ldap_set_cachesize_slot(cmd_parms *parms,
-	void *mconfig, const char *arg) {
-	authz_ldap_config_rec	*sec;
-	sec = (authz_ldap_config_rec *)mconfig;
-
-#if AUTHZ_LDAP_DEBUG
-	fprintf(stderr, "%s:%d: setting cachesize at %p to '%s'\n",
-		__FILE__, __LINE__, (void *)sec, (arg) ? arg : "(null)");
-#endif
-
-	sec->cachesize = atoi(arg);
-	if ((sec->cachesize < 0) || (sec->cachesize > AUTHZ_MAX_CACHE_SIZE)) {
-		ap_log_error(APLOG_MARK, APLOG_ERR, APLOG_STATUS parms->server,
-			"[%d] illegal LDAP cache size: %d, cache disabled",
-			(int)getpid(), sec->cachesize);
-		sec->cachesize = 0;
-	}
-	return NULL;
-}
-
-#endif /* HAVE_LDAP_ENABLE_CACHE */
-
 static const char	*authz_ldap_set_version_slot(cmd_parms *parms,
 	void *mconfig, const char *arg) {
 	authz_ldap_config_rec	*sec;
 	sec = (authz_ldap_config_rec *)mconfig;
 
-#if AUTHZ_LDAP_DEBUG
-	fprintf(stderr, "%s:%d: setting ldap version at %p to '%s'\n",
-		__FILE__, __LINE__, (void *)sec, (arg) ? arg : "(null)");
-#endif
+	AUTHZ_DEBUG("setting ldap version at %x to '%s'", parms->server,
+		(void *)sec, (arg) ? arg : "(null)");
 
 	sec->ldapversion = atoi(arg);
 	if (0 == sec->ldapversion) {
 		ap_log_error(APLOG_MARK, APLOG_WARNING,
-			APLOG_STATUS parms->server,
+			0, parms->server,
 			"[%d] version cannot be set: %s", (int)getpid(),
 			arg);
 	}
@@ -217,10 +134,8 @@ static const char	*authz_ldap_set_method_slot(cmd_parms *parms,
 	authz_ldap_config_rec	*sec;
 	sec = (authz_ldap_config_rec *)mconfig;
 
-#if AUTHZ_LDAP_DEBUG
-	fprintf(stderr, "%s:%d: setting auth method at %p to '%s'\n",
-		__FILE__, __LINE__, (void *)sec, (arg) ? arg : "(null)");
-#endif
+	AUTHZ_DEBUG("setting auth method at %x to '%s'", parms->server,
+		(void *)sec, (arg) ? arg : "(null)");
 
 	sec->method = AUTHMETHOD_NONE;
 	if (0 == strcasecmp(arg, "certificate")) {
@@ -249,10 +164,8 @@ static const char	*authz_ldap_set_mapmethod_slot(cmd_parms *parms,
 	authz_ldap_config_rec	*sec;
 	sec = (authz_ldap_config_rec *)mconfig;
 
-#if AUTHZ_LDAP_DEBUG
-	fprintf(stderr, "%s:%d: setting map method at %p to '%s'\n",
-		__FILE__, __LINE__, (void *)sec, (arg) ? arg : "(null)");
-#endif
+	AUTHZ_DEBUG("setting map method at %x to '%s'", parms->server,
+		(void *)sec, (arg) ? arg : "(null)");
 
 	sec->mapmethod = AUTHMAPMETHOD_NONE;
 	if (0 == strcasecmp(arg, "certificate")) {
@@ -279,18 +192,13 @@ static const char	*authz_ldap_set_setauth_slot(cmd_parms *parms,
 	authz_ldap_config_rec	*sec;
 	sec = (authz_ldap_config_rec *)mconfig;
 
-#if AUTHZ_LDAP_DEBUG
-	fprintf(stderr, "%s:%d: setting authoriziation header at %p to '%s'\n",
-		__FILE__, __LINE__, (void *)sec, (arg) ? arg : "(null)");
-#endif
+	AUTHZ_DEBUG("setting authoriziation header at %x to '%s'",
+		parms->server, (void *)sec, (arg) ? arg : "(null)");
 
 	sec->setauth = AUTHHEADER_NONE;
 	if (NULL != strstr(arg, "+password")) {
 		sec->setauth |= AUTHHEADER_PASSWORD;
-#if AUTHZ_LDAP_DEBUG
-		fprintf(stderr, "%s:%d: password requested\n",
-			__FILE__, __LINE__);
-#endif
+		AUTHZ_DEBUG("password requested: %s\n", parms->server, arg);
 	}
 	if (0 == strncasecmp(arg, "user", 4)) {
 		sec->setauth |= AUTHHEADER_USER;
@@ -316,10 +224,8 @@ static const char	*authz_ldap_set_setgroup_slot(cmd_parms *parms,
 	authz_ldap_config_rec   *sec;
 	sec = (authz_ldap_config_rec *)mconfig;
 	
-#if AUTHZ_LDAP_DEBUG
-	fprintf(stderr, "%s:%d: setting group attribute at %p to '%s'\n",
-		__FILE__, __LINE__, (void *)sec, (arg) ? arg : "(null)");
-#endif	 
+	AUTHZ_DEBUG("setting group attribute at %x to '%s'", parms->server,
+		(void *)sec, (arg) ? arg : "(null)");
 
 	sec->setgroup = AUTHHEADER_USER;
 	
@@ -503,23 +409,6 @@ const command_rec	authz_ldap_cmds[] = {
 		"Key to look for when trying to check for the last modification"
 	),
 
-#ifdef HAVE_LDAP_ENABLE_CACHE
-	/* LDAP cache size						*/
-	AP_INIT_TAKE1(
-		"AuthzLDAPCacheTimeout", authz_ldap_set_timeout_slot,
-		(void *)APR_OFFSETOF(authz_ldap_config_rec, timeout),
-		OR_AUTHCFG,
-		"Timout for entries in the LDAP cache in seconds, default 600, "
-		"i.e. 10 minutes"
-	),
-	AP_INIT_TAKE1(
-		"AuthzLDAPCacheSize", authz_ldap_set_cachesize_slot,
-		(void *)APR_OFFSETOF(authz_ldap_config_rec, cachesize),
-		OR_AUTHCFG,
-		"Size of the LDAP cache, default 0, i.e. no caching"
-	),
-#endif /* HAVE_LDAP_ENABLE_CACHE */
-
 	/* general variables						*/
 	AP_INIT_FLAG(
 		"AuthzLDAPAuthoritative", ap_set_flag_slot,
@@ -547,12 +436,8 @@ const command_rec	authz_ldap_cmds[] = {
 /* initialize a directory configuration record				*/
 void	*authz_ldap_create_dir_config(apr_pool_t *p, char *d) {
 	authz_ldap_config_rec	*sec
-		= (authz_ldap_config_rec *)ap_palloc(p,
+		= (authz_ldap_config_rec *)apr_palloc(p,
 			sizeof(authz_ldap_config_rec));
-#if AUTHZ_LDAP_DEBUG
-	fprintf(stderr, "%s:%d: initializing dir config record at %p\n",
-		__FILE__, __LINE__, (void *)sec);
-#endif
 	if (sec) {
 		/* don't be active/caching connections by default	*/
 		sec->method = AUTHMETHOD_NONE;
@@ -599,12 +484,6 @@ void	*authz_ldap_create_dir_config(apr_pool_t *p, char *d) {
 		/* password aging					*/
 		sec->modifykey = NULL;
 
-#ifdef HAVE_LDAP_ENABLE_CACHE
-		/* LDAP cache						*/
-		sec->timeout = AUTHZ_DEFAULT_CACHE_TIMEOUT;
-		sec->cachesize = 0;	/* disabled by default		*/
-#endif /* HAVE_LDAP_ENABLE_CACHE */
-
 		/* generic configuration				*/
 		sec->authoritative = 1;
 		sec->proxyauth = AUTHZ_AUTO;
@@ -623,10 +502,6 @@ void	*authz_ldap_create_dir_config(apr_pool_t *p, char *d) {
 void	*authz_ldap_merge_dir_config(apr_pool_t *p, void *pp, void *cp) {
 	authz_ldap_config_rec	*parent = (authz_ldap_config_rec *)pp;
 	authz_ldap_config_rec	*child = (authz_ldap_config_rec *)cp;
-#ifdef AUTHZ_LDAP_DEBUG	
-	fprintf(stderr, "%s:%d: merging from %p to %p\n",
-		__FILE__, __LINE__, pp, cp);
-#endif
 	
 	/* all values that were not set in the child but are set in the	*/
 	/* parent are linked						*/
